@@ -1,14 +1,13 @@
-'''Abstract crash database interface.
+'''Abstract crash database interface.'''
 
-Copyright (C) 2007 Canonical Ltd.
-Author: Martin Pitt <martin.pitt@ubuntu.com>
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
-option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
-the full text of the license.
-'''
+# Copyright (C) 2007 - 2009 Canonical Ltd.
+# Author: Martin Pitt <martin.pitt@ubuntu.com>
+# 
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; either version 2 of the License, or (at your
+# option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
+# the full text of the license.
 
 import os, os.path, datetime, sys
 
@@ -346,14 +345,34 @@ class CrashDatabase:
 
         raise NotImplementedError, 'this method must be implemented by a concrete subclass'
 
-    def update(self, id, report, comment):
-        '''Update the given report ID for retracing results.
+    def update(self, id, report, comment, change_description=False,
+            attachment_comment=None, key_filter=None):
+        '''Update the given report ID with all data from report.
+
+        This creates a text comment with the "short" data (see
+        ProblemReport.write_mime()), and creates attachments for all the
+        bulk/binary data. 
         
-        This updates Stacktrace, ThreadStacktrace, StacktraceTop, and
-        Disassembly. You can also supply an additional comment.
+        If change_description is True, and the crash db implementation supports
+        it, the short data will be put into the description instead (like in a
+        new bug).
+
+        comment will be added to the "short" data. If attachment_comment is
+        given, it will be added to the attachment uploads.
+
+        If key_filter is a list or set, then only those keys will be added.
         '''
         raise NotImplementedError, 'this method must be implemented by a concrete subclass'
 
+    def update_traces(self, id, report, comment=''):
+        '''Update the given report ID for retracing results.
+        
+        This updates Stacktrace, ThreadStacktrace, StacktraceTop,
+        and StacktraceSource. You can also supply an additional comment.
+        '''
+        self.update(id, report, comment, key_filter=['Stacktrace',
+            'ThreadStacktrace', 'StacktraceSource', 'StacktraceTop'])
+
     def set_credentials(self, username, password):
         '''Set username and password.'''
 
@@ -406,6 +425,26 @@ class CrashDatabase:
         '''
         raise NotImplementedError, 'this method must be implemented by a concrete subclass'
 
+    def get_affected_packages(self, id):
+        '''Return list of affected source packages for given ID.'''
+
+        raise NotImplementedError, 'this method must be implemented by a concrete subclass'
+
+    def is_reporter(self, id):
+        '''Check whether the user is the reporter of given ID.'''
+
+        raise NotImplementedError, 'this method must be implemented by a concrete subclass'
+
+    def can_update(self, id):
+        '''Check whether the user is eligible to update a report.
+
+        A user should add additional information to an existing ID if (s)he is
+        the reporter or subscribed, the bug is open, not a duplicate, etc. The
+        exact policy and checks should be done according to  the particular
+        implementation.
+        '''
+        raise NotImplementedError, 'this method must be implemented by a concrete subclass'
+
     def duplicate_of(self, id):
         '''Return master ID for a duplicate bug.
 
