@@ -1,21 +1,31 @@
-'''Python sys.excepthook hook to generate apport crash dumps.
+'''Python sys.excepthook hook to generate apport crash dumps.'''
 
-See https://wiki.ubuntu.com/AutomatedProblemReports for details.
-
-Copyright (c) 2006 Canonical Ltd.
-Authors: Robert Collins <robert@ubuntu.com>
-         Martin Pitt <martin.pitt@ubuntu.com>
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
-option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
-the full text of the license.
-'''
+# Copyright (c) 2006 - 2009 Canonical Ltd.
+# Authors: Robert Collins <robert@ubuntu.com>
+#          Martin Pitt <martin.pitt@ubuntu.com>
+# 
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; either version 2 of the License, or (at your
+# option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
+# the full text of the license.
 
 import os
 import sys
 
+CONFIG = '/etc/default/apport'
+
+def enabled():
+    '''Return whether Apport should generate crash reports.'''
+
+    import re
+    try:
+        conf = open(CONFIG).read()
+        return re.search('^\s*enabled\s*=\s*0\s*$', conf, re.M) is None
+    except IOError:
+        # if the file does not exist, assume it's enabled
+        return True
+
 def apport_excepthook(exc_type, exc_obj, exc_tb):
     '''Catch an uncaught exception and make a traceback.'''
 
@@ -35,12 +45,7 @@ def apport_excepthook(exc_type, exc_obj, exc_tb):
             return
 
         # do not do anything if apport was disabled
-        try:
-            from apport.packaging_impl import impl as packaging
-        except ImportError:
-            # LP #348250; inexplicable, but better than wreaking havoc
-            return
-        if not packaging.enabled():
+        if not enabled():
             return
 
         from cStringIO import StringIO
@@ -97,8 +102,7 @@ def apport_excepthook(exc_type, exc_obj, exc_tb):
                 # don't clobber existing report
                 return
         report_file = os.fdopen(os.open(pr_filename,
-            os.O_WRONLY|os.O_CREAT|os.O_EXCL), 'w')
-        os.chmod(pr_filename, 0600)
+            os.O_WRONLY|os.O_CREAT|os.O_EXCL, 0600), 'w')
         try:
             pr.write(report_file)
         finally:
@@ -124,7 +128,7 @@ if __name__ == '__main__':
     import unittest, tempfile, subprocess, os.path, stat
     import apport.fileutils, problem_report
 
-    class _PythonHookTest(unittest.TestCase):
+    class _T(unittest.TestCase):
         def test_env(self):
             '''Check the test environment.'''
 
